function module (config, errback) {
  "use strict";

  var exports = {},
     _ = require('underscore'),
     async = require('async'),
     timer,
     writeFile = require('fs').writeFile,
     fs = require('fs'),
     rename = require('fs').rename,
     log = config.log,
     statusData = {},
     indexer = require('../models/socindex/indexer');

  function status (callback) {
    callback(null, statusData);
  }

  function index () {
    log.info('soc: indexing');
    var emitter = indexer(function (error, data) {
      if (error) errback(error);
      else {
        log.info('soc: scrape complete, writing files');
        async.forEach(data, function (item, callback) {
          writeFile(
            config.paths.temp + '/indexes/' + item.filename,
            JSON.stringify(item.data),
            callback
          );

        }, function (error) {
          if (error) errback(error);
          else {
            log.info('soc: files written, moving files');
            async.forEach(data, function (item, callback) {
              rename(
                config.paths.temp + '/indexes/' + item.filename,
                config.paths.output + '/indexes/' + item.filename,
                callback
              );

            }, function (error) {
              if (error) errback(error);
              else log.info('soc: done');
            });
          }
        });
      }
    });

    //emitter.on('debug', function (msg) { log.info(msg); });
  }

  function start () {
    log.info('soc: starting');
    fs.mkdir(config.paths.temp + '/indexes');
    fs.mkdir(config.paths.output + '/indexes');
    timer = setInterval(index, Number(config.modules.soc.interval) * 1000 * 60);
    index();
  }

  function shutdown (done) {
    clearInterval(timer);
    done();
  }

  exports.start = start;
  exports.shutdown = shutdown;
  exports.status = status;

  return exports;
}

exports.module = module;
